@@ -3,9 +3,11 @@ Main interface for accessanalyzer service type definitions.
 
 Usage::
 
-    from mypy_boto3.accessanalyzer.type_defs import AnalyzedResourceSummaryTypeDef
+    ```python
+    from mypy_boto3_accessanalyzer.type_defs import AnalyzedResourceSummaryTypeDef
 
     data: AnalyzedResourceSummaryTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
